// CHoopsView.h : interface of the CHoopsView class, derived from CView
// Adds encapsulation of a HOOPS View Object, which corresponds to an
// instance of a HOOPS driver
//
// Also provides high-level support for copying the view to the clipboard, 
// printing and printpreview

#ifndef hoops_view
#define hoops_view


#include "HBaseView.h"

class CHoopsDoc;

// msw driver specific driver_option debug flags
#define DEBUG_NO_WINDOWS_HOOK			0x00000040
#define DEBUG_FORCE_FULL_COLOR			0x00000010
#define DEBUG_SFB_COPY_TO_CLIPBOARD		0x00004000
#define DEBUG_NO_RASTERS_IN_PRINTING	0x00020000
#define DEBUG_PRINTING_MODE				0x00040000
#define DEBUG_CLIPBOARD_MODE			0x00080000

#define WMF             0
#define EMF             1

// generic rendering options debug flags
#define DEBUG_NO_PAINTERS_PANELLING	0x00000008


class AFX_EXT_CLASS CHoopsView : public CView
{
protected: // create from serialization only
	CHoopsView();
	DECLARE_DYNCREATE(CHoopsView)

    CPalette		*m_view_palette;	// ptr to the this view's unique palette

	bool			m_fast_print;		// flag enabling print optimization
	bool		    m_meta_print;		// flag enabling playing a metafile to the printer
	bool			m_clipboard_truecolor;	// flag enabling clipboard truecolor support
	int				m_metafile_type;	// metafile type can be WMF or EMF

	HBaseView*		m_pHView;			// ptr to the Hoops View object associated with this CView
										// HBaseView serves as a wrapper class for a HOOPS Driver Instance segment
										// (which represents a connection to a device; e.g. a screen window)


	long			m_view_key;			// key of the HOOPS driver instance segment associated with this view
										// intended to be used as an ALTERNATIVE to an HBaseView object (m_pHView)

	long			m_scene_key;		// key of the HOOPS segment representing the scene, typically a subsegment
										// of the driver instance segment (m_view_key)  This is intended to be
										// used in conjunction with m_view_key, in lieu of using HBaseView
    
// Operations
public:
	CHoopsDoc* GetDocument();

	HBaseView* GetHoopsView( void ) { return m_pHView; }

	// palette
    CPalette*   GetPalette();
    void        InitializePalette();

	// printing and metafile methods
    bool        GetFastPrint(){return m_fast_print;};
    void        SetFastPrint(bool fastprint){m_fast_print = fastprint;};

	bool        GetMetaPrint(){return m_meta_print;};
    void        SetMetaPrint(bool metaprint){m_meta_print = metaprint;};

	BOOL		GetClipboardTruecolor() { return m_clipboard_truecolor; };
    int			GetMetafileType() { return m_metafile_type; };
    void		SetClipboardTruecolor(bool truecolor) { m_clipboard_truecolor = truecolor; };
    void		SetMetafileType(int emf_or_wmf) { m_metafile_type = emf_or_wmf; };

	long		GetViewKey();
	long		GetSceneKey();

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CHoopsView)
	public:
	virtual void OnDraw(CDC* pDC);  // overridden to draw this view
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual void OnInitialUpdate();
	virtual BOOL Create(LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext = NULL);
	protected:
	virtual BOOL OnPreparePrinting(CPrintInfo* pInfo);
	virtual void OnBeginPrinting(CDC* pDC, CPrintInfo* pInfo);
	virtual void OnEndPrinting(CDC* pDC, CPrintInfo* pInfo);
	virtual void OnPrint(CDC* pDC, CPrintInfo* pInfo);
	//}}AFX_VIRTUAL

// Implementation
public:
	virtual ~CHoopsView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generated message map functions
protected:
	//{{AFX_MSG(CHoopsView)
	afx_msg void OnPaint();
	afx_msg void OnEditCopy();
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyUp(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnRButtonDblClk(UINT nFlags, CPoint point);
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnRButtonUp(UINT nFlags, CPoint point);
	afx_msg BOOL OnSetCursor(CWnd* pWnd, UINT nHitTest, UINT message);
	afx_msg void OnTimer(UINT nIDEvent);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

#ifndef _DEBUG  // debug version in hoopsView.cpp
inline CHoopsDoc* CHoopsView::GetDocument()
   { return (CHoopsDoc*)m_pDocument; }
#endif

#endif

/////////////////////////////////////////////////////////////////////////////
